@@ -1,9 +1,10 @@
 import av
 import av.datasets
 
+av.logging.set_level(av.logging.VERBOSE)
 
-input_ = av.open(av.datasets.curated('pexels/time-lapse-video-of-night-sky-857195.mp4'))
-output = av.open('remuxed.mkv', 'w')
+input_ = av.open(av.datasets.curated("pexels/time-lapse-video-of-night-sky-857195.mp4"))
+output = av.open("remuxed.mkv", "w")
 
 # Make an output stream using the input as a template. This copies the stream
 # setup from one to the other.
@@ -11,7 +12,6 @@ in_stream = input_.streams.video[0]
 out_stream = output.add_stream(template=in_stream)
 
 for packet in input_.demux(in_stream):
-
     print(packet)
 
     # We need to skip the "flushing" packets that `demux` generates.
@@ -23,4 +23,5 @@ for packet in input_.demux(in_stream):
 
     output.mux(packet)
 
+input_.close()
 output.close()
